@@ -1,5 +1,5 @@
 -- TE4 - T-Engine 4
--- Copyright (C) 2009 - 2018 Nicolas Casalini
+-- Copyright (C) 2009 - 2019 Nicolas Casalini
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -744,6 +744,83 @@ function _M:orderAddonAuthoring(o)
 		end
 	end
 end
+
+function _M:orderMicroTxn(o)
+	if o.suborder == "get_actionables" then
+		self:command("MTXN GET_ACTIONABLES", o.module)
+		if self:read("200") then
+			local _, _, size = self.last_line:find("^([0-9]+)")
+			size = tonumber(size)
+			local body = {}
+			if size and size > 1 then
+				body = self:receive(size)
+				if body then body = zlib.decompress(body) end
+			end
+
+			cprofile.pushEvent(("e='MicroTxnListActionables' list=%q"):format(body))
+			return
+		else
+			cprofile.pushEvent(("e='MicroTxnListActionables' error=%q"):format(self.last_error))
+		end
+	elseif o.suborder == "use_actionable" then
+		self:command("MTXN USE_ACTIONABLE", o.module, o.id_purchasable)
+		if self:read("200") then
+			cprofile.pushEvent(("e='MicroTxnUseActionable' success=true"):format())
+		else
+			cprofile.pushEvent(("e='MicroTxnUseActionable' success=false error=%q"):format(tostring(self.last_error)))
+		end
+	elseif o.suborder == "list_purchasables" then
+		self:command("MTXN LIST_PURCHASABLE", o.module, o.store)
+		if self:read("200") then
+			local _, _, size = self.last_line:find("^([0-9]+)")
+			size = tonumber(size)
+			local body = {}
+			if size and size > 1 then
+				body = self:receive(size)
+				if body then body = zlib.decompress(body) end
+			end
+
+			cprofile.pushEvent(("e='MicroTxnListPurchasables' data=%q"):format(body))
+			return
+		else
+			cprofile.pushEvent(("e='MicroTxnListPurchasables' error=%q"):format(self.last_error))
+		end
+	elseif o.suborder == "create_cart" then
+		local data = table.serialize{module=o.module, store=o.store, cart=o.cart:unserialize()}
+		self:command("MTXN CREATE_CART ", #data)
+		if self:read("200") then
+			self.sock:send(data)
+			if self:read("200") then
+				cprofile.pushEvent(("e='MicroTxnListCartResult' success=true info=%q"):format(self.last_line))
+			else
+				cprofile.pushEvent(("e='MicroTxnListCartResult' success=false"):format())
+			end
+		end
+	elseif o.suborder == "steam_finalize_cart" then
+		local data = table.serialize{module=o.module, store=o.store, id_cart=o.id_cart}
+		self:command("MTXN STEAM_FINALIZE_CART ", #data)
+		if self:read("200") then
+			self.sock:send(data)
+			if self:read("200") then
+				cprofile.pushEvent(("e='MicroTxnSteamFinalizeCartResult' success=true new_donated=%d"):format(tonumber(self.last_line)))
+			else
+				cprofile.pushEvent(("e='MicroTxnSteamFinalizeCartResult' success=false"):format())
+			end
+		end
+	elseif o.suborder == "te4_finalize_cart" then
+		local data = table.serialize{module=o.module, store=o.store, id_cart=o.id_cart}
+		self:command("MTXN TE4_FINALIZE_CART ", #data)
+		if self:read("200") then
+			self.sock:send(data)
+			if self:read("200") then
+				cprofile.pushEvent(("e='MicroTxnTE4FinalizeCartResult' success=true new_donated=%d"):format(tonumber(self.last_line)))
+			else
+				cprofile.pushEvent(("e='MicroTxnTE4FinalizeCartResult' success=false"):format())
+			end
+		end
+	end
+end
+
 --------------------------------------------------------------------
 -- Pushes comming from the push socket
 --------------------------------------------------------------------
